@@ -41,6 +41,7 @@ from starlite.exceptions import (
     ImproperlyConfiguredException,
     InternalServerException,
     MissingDependencyException,
+    NoRouteMatchFoundException,
     NotAuthorizedException,
     NotFoundException,
     PermissionDeniedException,
@@ -111,6 +112,7 @@ __all__ = (
     "MediaType",
     "MiddlewareProtocol",
     "MissingDependencyException",
+    "NoRouteMatchFoundException",
     "NotAuthorizedException",
     "NotFoundException",
     "OpenAPIConfig",
