@@ -4,7 +4,7 @@ from pydantic import BaseConfig, BaseModel
 from pydantic_openapi_schema.v3_1_0 import SecurityRequirement
 
 from starlite.connection import Request, WebSocket
-from starlite.datastructures.provide import Provide
+from starlite.datastructures import CacheControlHeader, ETag, Provide
 from starlite.plugins.base import PluginProtocol
 from starlite.types import (
     AfterExceptionHookHandler,
@@ -103,6 +103,11 @@ class AppConfig(BaseModel):
     """
     Configures caching behavior of the application.
     """
+    cache_control: Optional[CacheControlHeader]
+    """
+    A `cache-control` header of type [CacheControlHeader][starlite.datastructures.CacheControlHeader] to add to
+    route handlers of this app. Can be overridden by route handlers.
+    """
     compression_config: Optional[CompressionConfig]
     """
     Configures compression behaviour of the application, this enabled a builtin or user defined Compression middleware.
@@ -123,6 +128,11 @@ class AppConfig(BaseModel):
     """
     A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
     """
+    etag: Optional[ETag]
+    """
+        An `etag` header of type [ETag][starlite.datastructures.ETag] to add to route handlers of this app.
+        Can be overridden by route handlers.
+    """
     exception_handlers: ExceptionHandlersMap
     """
     A dictionary that maps handler functions to status codes and/or exception types.
