@@ -1,8 +1,7 @@
 from typing import TYPE_CHECKING, Any, Optional, cast
 
 from starlite.types import Empty
-from starlite.utils.predicates import is_async_callable
-from starlite.utils.sync import AsyncCallable
+from starlite.utils.sync import AsyncCallable, is_async_callable
 
 if TYPE_CHECKING:
     from typing import Type
